@@ -1,9 +1,9 @@
 
-      FUNCTION fp0(v,i)
+      FUNCTION fp0(v)
       DOUBLE PRECISION logL,fp0,z,v,
      *bt1,beta1,rho1,x1,theta1,work1,
      *omega1
-      INTEGER m,mpar,y1,i,maxy1,link1
+      INTEGER m,mpar,y1,maxy1,link1
 
       DIMENSION x1(4000,10),theta1(4000),
      *work1(4000),y1(4000),beta1(10),bt1(10)
